<div align="center">
  <img src=https://github.com/Quantum-Accelerators/quacc/blob/main/docs/images/quacc_logo_wide.png width="300"><br>
</div>

# `quacc` – The Quantum Accelerator 🦆

![tests](https://github.com/quantum-accelerators/quacc/actions/workflows/tests.yaml/badge.svg)
[![codecov](https://codecov.io/gh/Quantum-Accelerators/quacc/branch/main/graph/badge.svg?token=OJaOZAH30u)](https://codecov.io/gh/Quantum-Accelerators/quacc)
[![DeepSource](https://app.deepsource.com/gh/Quantum-Accelerators/quacc.svg/?label=active+issues&token=Y1NxOLIuFFEqWdjawIYnJNde)](https://app.deepsource.com/gh/Quantum-Accelerators/quacc/?ref=repository-badge)
![PyPI - Version](https://img.shields.io/pypi/v/quacc?color=blue)
![Python - Version](https://img.shields.io/pypi/pyversions/quacc)
[![DOI](https://zenodo.org/badge/DOI/10.5281/zenodo.7720998.svg)](https://doi.org/10.5281/zenodo.7720998)

`quacc` is a flexible platform for computational materials science 💎 and quantum chemistry 🧪 that is built for the exascale era 🔥. It is maintained by the [Rosen Research Group](https://rosen.cbe.princeton.edu/) at Princeton University 🐯.

- `quacc` makes it possible to easily write complex workflows that can be run anywhere, anyhow. By anywhere, we mean locally, HPC, the cloud, or any combination thereof. By anyhow, we mean via one of several [modern workflow management solutions](https://workflows.community).

- `quacc` doesn't try to reinvent the wheel. It is built around the [Atomic Simulation Environment](https://wiki.fysik.dtu.dk/ase/) and much of the software infrastructure powering the [Materials Project](https://materialsproject.org).

- `quacc` gives you the freedom of choice. Through a single, unified interface to several [supported workflow management solutions](https://quantum-accelerators.github.io/quacc/user/basics/wflow_overview.html), `quacc` lets you use what best suits your unique computing needs.

- `quacc` has [pre-made recipes](https://quantum-accelerators.github.io/quacc/user/recipes/recipes_list.html) for the following packages: DFTB+, Gaussian, GULP, NewtonNet, ORCA, Psi4, Q-Chem, tblite, and VASP. It's simple to add your favorite!

## Documentation

<p align="center">
  📖 <a href="https://quantum-accelerators.github.io/quacc/"><b><i>Learn More Here!</i></b></a> 📖
</p>

Includes the following sections:

- 🏎️ [Test Drive](https://quantum-accelerators.github.io/quacc/start/demo.html)
- 🔧 [Installation Guide](https://quantum-accelerators.github.io/quacc/install/install.html)
- 🧠 [User Guide](https://quantum-accelerators.github.io/quacc/user/recipes/recipes_intro.html)
- 🤝 [Developer Guide](https://quantum-accelerators.github.io/quacc/dev/contributing.html)

## Demonstration ✨

🚀 Demo from the Quick Start guide, using [Covalent](https://github.com/AgnostiqHQ/covalent) as one of the [several supported workflow managers](https://quantum-accelerators.github.io/quacc/user/basics/wflow_overview.html).

![](https://github.com/Quantum-Accelerators/quacc/blob/main/docs/images/start/start.gif)

## Citation

If you use `quacc` in your work, please cite it as follows:

- quacc – The Quantum Accelerator, https://doi.org/10.5281/zenodo.7720998.

## License ⚖️

`quacc` is released under a [BSD 3-Clause license](https://github.com/quantum-accelerators/quacc/blob/main/LICENSE.md).
